@@ -2,20 +2,20 @@ import numpy as np
 import pandas as pd
 import pytest
 
-import tabmat as mx
+import tabmat as tm
 
 
 @pytest.fixture()
 def X():
     df = pd.read_pickle("tests/real_matrix.pkl")
-    X_split = mx.from_pandas(df, np.float64)
+    X_split = tm.from_pandas(df, np.float64)
     wts = np.ones(df.shape[0]) / df.shape[0]
     X_std = X_split.standardize(wts, True, True)[0]
     return X_std
 
 
 def test_full_sandwich(X):
-    X_dense = mx.DenseMatrix(X.toarray())
+    X_dense = tm.DenseMatrix(X.toarray())
     r = np.random.rand(X.shape[0])
     simple = X_dense.sandwich(r)
     fancy = X.sandwich(r)
@@ -24,7 +24,7 @@ def test_full_sandwich(X):
 
 def test_split_sandwich_rows_cols(X):
     X_split = X.mat
-    X_split_dense = mx.DenseMatrix(X_split.toarray())
+    X_split_dense = tm.DenseMatrix(X_split.toarray())
     r = np.random.rand(X.shape[0])
     rows = np.arange(X.shape[0])
     cols = np.arange(X.shape[1])
